#
# spec file for package ido
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libido3-0_1-0
%define soname  libido3-0.1
%define sover   0
%define typelib typelib-1_0-Ido3-0_1
%define _version 13.10.0+17.04.20161028
Name:           ido
Version:        13.10.0+bzr20161028
Release:        4.1
Summary:        Indicator Display Objects
License:        GPL-3.0-only AND LGPL-3.0-only AND LGPL-2.1-only
Group:          System/GUI/Other
Url:            https://launchpad.net/ido
Source:         https://launchpad.net/ubuntu/+archive/primary/+files/%{name}_%{_version}.orig.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE ido-optional-ubuntu-private.patch sor.alexei@meowr.ru -- Make Ubuntu GTK+ Private API optional.
Patch0:         ido-optional-ubuntu-private.patch
# PATCH-FIX-OPENSUSE ido-fix-maintainer-cflags.patch dimstar@opensuse.org -- Strip -Werror from unconditional CFLAGS. This is part of maintainer_CFLAGS; fixes build with more recent toolchains/gnome stacks
Patch1:         ido-fix-maintainer-cflags.patch
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.16
BuildRequires:  pkgconfig(gio-2.0) >= 2.37.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.37.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(xorg-macros)

%description
Widgets and other objects used for indicators.

%package -n %{lname}
Summary:        Shared library providing extra GTK+ menu items in system indicators
Group:          System/Libraries

%description -n %{lname}
Shared library providing extra GTK+ menu items for display in
system indicators.

This package contains shared libraries.

%package -n %{typelib}
Summary:        Indicator Display Objects typelib
Group:          System/Libraries

%description -n %{typelib}
Shared library providing extra GTK+ menu items for display in
system indicators.

This package provides the GObject Introspection bindings for Ido.

%package devel
Summary:        Development files for Indicator Display Objects
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       %{typelib} = %{version}
Requires:       pkgconfig(gio-2.0) >= 2.37.0
Requires:       pkgconfig(glib-2.0) >= 2.37.0
Requires:       pkgconfig(gobject-introspection-1.0)
Requires:       pkgconfig(gtk+-3.0) >= 3.8.2

%description devel
Shared library providing extra GTK+ menu items for display in
system indicators.

This package contains the development files for Ido.

%prep
%autosetup -c -p1

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure \
  --disable-ubuntu-private-api
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%if 0%{?suse_version} >= 1500
%license COPYING*
%else
%doc COPYING*
%endif
%doc AUTHORS NEWS
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{typelib}
%{_libdir}/girepository-1.0/Ido3-0.1.typelib

%files devel
%{_includedir}/%{soname}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{soname}.pc
%{_datadir}/gir-1.0/Ido3-0.1.gir
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/Ido3-0.1.vapi

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Oct 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add ido-fix-maintainer-cflags.patch: Do not pass -Werror
  unconditionally. This is already part of
  - -enable-maintainer-flags, which is default enabled on the
  unstable branch. For the stable branch, we accept new warnings
  coming from updated toolchains and gnome stacks.
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Change the source package RPM group to System/GUI/Other.
- Correct the licence: GPL-3.0-only AND LGPL-3.0-only AND
  LGPL-2.1-only.
- Fix the devel package description.
* Wed Mar 29 2017 sor.alexei@meowr.ru
- Update to version 13.10.0+bzr20161028:
  * IdoCalendarMenuItem: disconnect from parent signals on item
    destruction (lp#1506427).
- Improve and rename ido-no-ubuntu-private.patch to
  ido-optional-ubuntu-private.patch.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 13.10.0+bzr20151002 (changes since 13.10.0+20150319):
  * Add crash guard on ido_calendar_menu_item_key_press
    (lp#1350821).
  * Change misplaced g_return_val_if_fail().
- Minor spec cleanup.
* Mon May 18 2015 mailaender@opensuse.org
- update to version 13.10.0+15.04.20150319
* Sun Mar 15 2015 i@marguerite.su
- update version 13.10.0+15.04.20150130
* Wed Oct  8 2014 i@marguerite.su
- add util-macros-devel for pkgconfig(xorg-macros)
* Tue Jul  8 2014 i@marguerite.su
- update to 13.10.1.20140708
* Sat Oct  6 2012 nmo.marques@gmail.com
- Update to version 12.10.2
  + fix escape key behavior in calendar menuitem (lp#953757)
- From previous releases
  + remove gtk2 support
  + remove slider hack (lp#953757)
  + new widget IdoSwitchMenuItem
* Sat Aug 11 2012 nmo.marques@gmail.com
- Update pkgconfig() calls for 'libgeis'; upstream name change
* Sat Aug 11 2012 nmo.marques@gmail.com
- Initial package
